@echo off
setlocal

rem *************************************************
rem Define default values for command arguments
rem *************************************************
set silent=
set unreg=
set INSTALL_DIR=C:\Program Files\IBM\Rational\SDP\6.0
set CDA_VERSION=6.0.1.103
set PRODUCT=rsa

rem *************************************************
rem Parse the command line arguments and override the default values.
rem *************************************************
set install_dir_arg=
:WHILE
if "%1" == "" goto WHILE_END
    if "%1" == "-unreg" (
		set unreg=true
		goto NEXT )
    if "%1" == "-silent" (
		set silent=/s
		goto NEXT )
    if "%1" == "-version" (
		set CDA_VERSION=%2
		shift
		goto NEXT )
    if "%1" == "-product" (
		set PRODUCT=%2
		shift
		goto NEXT )		
    if "%1" == "-dir" (
		set install_dir_arg=%2
		shift
		goto NEXT )
    if "%1" == "-help" (
		echo Syntax: "registerCDA_COM.bat [-unreg] [-silent] [-version <plug-in version number>] [-dir <root RSA install directory>]"
		echo The -dir arg must be last if defined and do NOT surround the directory in quotes.
		goto :eof )

    if not "%install_dir_arg%" == "" (
		set install_dir_arg=%install_dir_arg% %1
		goto NEXT )
	

:NEXT
    shift
    goto WHILE
:WHILE_END

if not "%install_dir_arg%" == "" set INSTALL_DIR=%install_dir_arg%



rem *************************************************
rem Determine the directories for the JRE and the CDA plug-in
rem *************************************************
set CDA_PLUGIN_DIR=%INSTALL_DIR%\%PRODUCT%\eclipse\plugins\com.ibm.uspm.cda_%CDA_VERSION%
set RSA_JRE_DIR=%INSTALL_DIR%\eclipse\jre


if not x%unreg% == x goto unregister

rem *************************************************
rem Perform the CDA_COM bridge registration
rem *************************************************

rem     Register the JVM
"%CDA_PLUGIN_DIR%\bridge\registerJavaVM" %silent% CDA_COM_JVM "%RSA_JRE_DIR%\bin\classic\jvm.dll" ^
-DCDA_DIRECTORY="%CDA_PLUGIN_DIR%" -Xj9 -DRJCB_TRACE ^
-Djava.class.path="%CDA_PLUGIN_DIR%\CDA_COM.jar;%CDA_PLUGIN_DIR%\bridge\RJCBRT.jar;%CDA_PLUGIN_DIR%\CommonDataAccess.jar;%CDA_PLUGIN_DIR%\CDAClient.jar;%CDA_PLUGIN_DIR%\CDAUtilities.jar"

rem     Register RJCBRT.dll
regsvr32 %silent% "%CDA_PLUGIN_DIR%\bridge\RJCBRT.dll"

rem     Register CDA_COMBridge.dll
regsvr32 %silent% "%CDA_PLUGIN_DIR%\bridge\CDA_COMBridge.dll"

rem     Register CDA_COM type library
"%CDA_PLUGIN_DIR%\bridge\registertypelibrary" %silent% "%CDA_PLUGIN_DIR%\bridge\CDA_COM.tlb"

rem     Register CDA_COM.Session RJCB class
"%CDA_PLUGIN_DIR%\bridge\registerjavaclass" %silent% CDA_COM.Session {09FF0C89-09CA-4bd8-88A9-B7E0D350D7F5} com.ibm.uspm.cda.client.rjcb.impl.SessionStub CDA_COM_JVM
goto :finished


rem *************************************************
rem Perform the CDA_COM bridge unregistration
rem *************************************************
:unregister
rem     Unregister JVM
"%CDA_PLUGIN_DIR%\bridge\registerJavaVM" /u %silent% CDA_COM_JVM 

rem     Unregister RJCBRT.dll
regsvr32 /u %silent% "%CDA_PLUGIN_DIR%\bridge\RJCBRT.dll"

rem     Unregister CDA_COMBridge.dll
regsvr32 /u %silent% "%CDA_PLUGIN_DIR%\bridge\CDA_COMBridge.dll"

rem     Unregister CDA_COM type library
"%CDA_PLUGIN_DIR%\bridge\registertypelibrary" /u %silent% "%CDA_PLUGIN_DIR%\bridge\CDA_COM.tlb"

rem     Unregister CDA_COM.Session RJCB class
"%CDA_PLUGIN_DIR%\bridge\registerjavaclass" /u %silent% CDA_COM.Session
goto :finished


:finished
if %errorlevel% neq 0 goto error
echo Registration complete!
goto :eof

:error
echo Error during registration.
goto :eof

:eof
pause

endlocal
